==> qtjambi-dbus-debuginfo-windows-x64-6.5.6.jar: sources/QtJambiDBus/QDBusInterface_shell.h <==
#ifndef QDBUSINTERFACE_SHELL_H
#define QDBUSINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDBus/qdbusinterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtDBus/qdbuspendingcall.h>
#include <QtJambi/RegistryAPI>


class QDBusInterface_shell : public QDBusInterface, public QtJambiShellInterface
{
public:
    QDBusInterface_shell(const QString& service0, const QString& path1, const QString& interface2 = QString(), const QDBusConnection& connection3 = QDBusConnection::sessionBus(), QObject* parent4 = nullptr);
    ~QDBusInterface_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusInterface_access : public QDBusInterface
{
};

#endif // QDBUSINTERFACE_SHELL_H

==> qtjambi-dbus-debuginfo-windows-x64-6.5.7.jar: sources/QtJambiDBus/QDBusInterface_shell.h <==
#ifndef QDBUSINTERFACE_SHELL_H
#define QDBUSINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDBus/qdbusinterface.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDBus/qdbusconnection.h>
#include <QtDBus/qdbuserror.h>
#include <QtDBus/qdbusmessage.h>
#include <QtDBus/qdbuspendingcall.h>
#include <QtJambi/RegistryAPI>


class QDBusInterface_shell : public QDBusInterface, public QtJambiShellInterface
{
public:
    QDBusInterface_shell(const QString& service0, const QString& path1, const QString& interface2 = QString(), const QDBusConnection& connection3 = QDBusConnection::sessionBus(), QObject* parent4 = nullptr);
    ~QDBusInterface_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QDBusInterface_mshell;
    friend class QDBusInterface_oshell;
};


class QDBusInterface_mshell : public QDBusInterface_shell
{
public:
    using QDBusInterface_shell::QDBusInterface_shell;
    static void operator delete(void * ptr) noexcept;
};


class QDBusInterface_oshell : public QDBusInterface_mshell
{
public:
    using QDBusInterface_mshell::QDBusInterface_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDBusInterface_access : public QDBusInterface
{
};

#endif // QDBUSINTERFACE_SHELL_H
